' INITIAL FLASH PROM CREATER FILE #1 By R. Diehl "Labguy" 20201106
'
' This program is for adding new individual color images to the image memory PROMs (R, G & B) for
' the 10-4 Eleanor NBTV Test Pattern Generator project at Labguy's World dot com. This program will
' modify the three separate output files containing 256 32x64x8 raw image files.
' These will be reformatted from 32x64 vertical orientation to 64x32 (and mirrored) horizontal
' orientation required to make the pixels flow from the bottom right, upward, and from right to left
' in vertical lines.
'
'
' The memory chip is a flash memory of brand and type: ST M29F040B, 4Mb or 512KB capacity
' 256 individual COLOR images with a resoluion of 32 x 64 x 8 bits will be placed into 3 EEPROM .bin files.
' Input data consists of raw uncompressed (3 x 8 bit) 24 bit video data in a 32x64 raster scanned format
' as produced by Paintshop pro 2020. This program will handle the data reformatting required by the
' signal generator circuit.
'
' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
'
CLS
PRINT "Image Prom File Modifier for Labguy's 10-4 Eleanor project"
PRINT
PRINT
'
' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
' INITIALIZE ALL PROGRAM VARIABLES
'
DIM DestFileRed AS STRING
DIM DestFileGrn AS STRING
DIM DestFileBlu AS STRING

DIM DestFileNumberRed AS _UNSIGNED LONG
DIM DestFileNumberGrn AS _UNSIGNED LONG
DIM DestFileNumberBlu AS _UNSIGNED LONG

DIM DestFilePointer AS _UNSIGNED LONG
DIM DestFileDataByte AS _UNSIGNED _BYTE

DIM SrcFile AS STRING
DIM SrcNum AS STRING
DIM SrcFileNumber AS _UNSIGNED LONG
DIM SrcFileCounter AS _UNSIGNED LONG
DIM SrcFilePxlCounter AS _UNSIGNED LONG
DIM SrcFilePointer AS _UNSIGNED LONG
DIM SrcFileDataByte AS _UNSIGNED _BYTE
DIM SrcFileDataByteRed AS _UNSIGNED _BYTE
DIM SrcFileDataByteGrn AS _UNSIGNED _BYTE
DIM SrcFileDataByteBlu AS _UNSIGNED _BYTE
DIM SrcFileIndex AS _UNSIGNED LONG

' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
' PATH and FILE names of all of our working data
' The path and name of the IMAGE ROM of all 256 images binary file

Path$ = "D:\DataFiles\HistoryData\HARDWARE_PROJECTS\_NBTV_TELEVISOR\004_10-4_Eleanor_RGBY\IMAGES_EEPROMS\RAW_IMAGE_FILES\"

' Get these frames from the "...\NumberedFrames" folder directly beneath this folder.
' NOTE the addition of a partial path string to the front of the actual file names.

DigitFile$ = Path$ + "NumberedFrames\Count_32x64x8_"

' The Red, Green and Blue output file name and path. These are the individual 524,288 byte
' frame buffer memory chip contents.
' Locate these three files in the folder above the "...\NumberedFrames" folder.

DestFileRed$ = Path$ + "ImagesRed.bin"
DestFileGrn$ = Path$ + "ImagesGrn.bin"
DestFileBlu$ = Path$ + "ImagesBlu.bin"

' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
' OPEN THE DESTINATION FILES, PROMPT THE USER FOR THE SOURCE FILE NAME AND DESTINATION FILE
' INDEX VALUE, OPEN THE SOURCE FILE, AND COPY THE DATA, BYTE BY BYTE, FROM SOURCE TO DESTINATION,
' AT LOCATION INICATATED BY THE USER PROVIDED INDEX NUMBER.
'
' Open the master destination files, clear the destination address pointers
DestFileNumberRed = FREEFILE
OPEN DestFileRed$ FOR BINARY AS #DestFileNumberRed
PRINT "Opening Red Destination File " + DestFileRed$

DestFileNumberGrn = FREEFILE
OPEN DestFileGrn$ FOR BINARY AS #DestFileNumberGrn
PRINT "Opening Grn Destination File " + DestFileGrn$

DestFileNumberBlu = FREEFILE
OPEN DestFileBlu$ FOR BINARY AS #DestFileNumberBlu
PRINT "Opening Blu Destination File " + DestFileBlu$

DestFilePointer = 0

' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
' Program Main Loop
MainLoop:

PRINT "Please take note. The input file must be a 32x64x3 byte RGB .raw formatted file"
PRINT "from PaintShop Pro 2020 or equivelant with a precise file size of 6,144 bytes."
PRINT "Your Source files MUST reside in the folder at this path:"
PRINT
PRINT Path$
PRINT

PRINT "Enter the name of the source file. Just press Enter to end": INPUT SrcFile$
IF SrcFile$ = "" THEN END
PRINT

PRINT "Enter destination file Index Number (0 - 255), enter the number 256, or larger to end"
INPUT SrcIndex

IF SrcFileIndex > 255 THEN END
IF SrcFileIndex < 0 THEN PRINT "Error: Value too low!": GOTO MainLoop


' - - - - - - - - - - - -
' IMAGE FILE COPY LOOP ROUTINE HERE

SrcFile$ = Path$ + SrcFile$

' Open the current source file, and copy it, byte by byte into the destination file
SrcFileNumber = FREEFILE
OPEN SrcFile$ FOR BINARY AS #SrcFileNumber

FOR SrcFilePxlCounter = 0 TO 2047

    y = 2047 - (32 * (SrcFilePxlCounter AND 63))
    x = 31 - (((2048 + (SrcFilePxlCounter AND 1984)) / 64) AND 31)
    SrcFilePointer = x + y
    DestFilePointer = (2048 * SrcIndex) + SrcFilePxlCounter

    GET #SrcFileNumber, SrcFilePointer + 1, SrcFileDataByteRed
    GET #SrcFileNumber, SrcFilePointer + 2049, SrcFileDataByteGrn
    GET #SrcFileNumber, SrcFilePointer + 4097, SrcFileDataByteBlu

    PUT #DestFileNumberRed, DestFilePointer + 1, SrcFileDataByteRed
    PUT #DestFileNumberGrn, DestFilePointer + 1, SrcFileDataByteGrn
    PUT #DestFileNumberBlu, DestFilePointer + 1, SrcFileDataByteBlu

NEXT SrcFilePxlCounter
CLOSE #SrcFileNumber

GOTO MainLoop

CLOSE
' #DestFileNumber

PRINT "All done!"
END


