' INITIAL FLASH PROM CREATER FILE #1 By R. Diehl "Labguy" 20201106
'
' This program is for creating the INITIAL three image memory PROMs (R, G & B) for the 10-4 Eleanor
' NBTV Test Pattern Generator project at Labguy's World dot com. This program will produce three
' separate output files containing the Count_32x64x8_nnn.raw files, where nnn = 000 to 255 decimal.
' These will be reformatted from 32x64 vertical orientation to 64x32 (and mirrored) horizontal
' orientation required to make the pixels flow from the bottom right, upward, and from right to left
' in vertical lines. Confused yet? So am I!
'
'
' The memory chip is a flash memory of brand and type: ST M29F040B, 4Mb or 512KB capacity
' 256 COLOR images with a resoluion of 32 x 64 x 8 bits will be placed into 3 EEPROM .bin files.
' Data consists of raw uncompressed (3 x 8 bit) 24 bit video data.
'
'
' First order coding completed in 20201112 at 14:00 hours. First three EEPROMS are loaded in the Eleanor
' rnd
'
'
CLS
PRINT "Initial Image Prom File Creator for Labguy's 10-4 Eleanor project"
'
'
' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
' INITIALIZE ALL PROGRAM VARIABLES
'
DIM DestFileRed AS STRING
DIM DestFileGrn AS STRING
DIM DestFileBlu AS STRING

DIM DestFileNumberRed AS _UNSIGNED LONG
DIM DestFileNumberGrn AS _UNSIGNED LONG
DIM DestFileNumberBlu AS _UNSIGNED LONG

DIM DestFilePointer AS _UNSIGNED LONG
DIM DestFileDataByte AS _UNSIGNED _BYTE

DIM SrcFile AS STRING
DIM SrcNum AS STRING
DIM SrcFileNumber AS _UNSIGNED LONG
DIM SrcFileCounter AS _UNSIGNED LONG
DIM SrcFilePxlCounter AS _UNSIGNED LONG
DIM SrcFilePointer AS _UNSIGNED LONG
DIM SrcFileDataByte AS _UNSIGNED _BYTE

' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
' PATH and FILE names of all of our working data
' The path and name of the IMAGE ROM of all 256 images binary file

Path$ = "D:\DataFiles\HistoryData\HARDWARE_PROJECTS\_NBTV_TELEVISOR\004_10-4_Eleanor_RGBY\IMAGES_EEPROMS\RAW_IMAGE_FILES\"

' Get these frames from the "...\NumberedFrames" folder directly beneath this folder.
' NOTE the addition of a partial path string to the front of the actual file names.

DigitFile$ = Path$ + "NumberedFrames\Count_32x64x8_"

' The Red, Green and Blue output file name and path. These are the individual 524,288 byte
' frame buffer memory chip contents.
' Locate these three files in the folder above the "...\NumberedFrames" folder.

DestFileRed$ = Path$ + "InitImagesRed.bin"
DestFileGrn$ = Path$ + "InitImagesGrn.bin"
DestFileBlu$ = Path$ + "InitImagesBlu.bin"

' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
' OPEN THE DESTINATION FILES, OVERWRITING THE EXISTING FILES, OPEN EACH SOURCE FILE IN TURN,
' AND COPY THE DATA, BYTE BY BYTE, FROM SOURCE TO DESTINATION.
'
' Open the master destination files, clear the destination address pointers
DestFileNumberRed = FREEFILE
OPEN DestFileRed$ FOR BINARY AS #DestFileNumberRed

DestFileNumberGrn = FREEFILE
OPEN DestFileGrn$ FOR BINARY AS #DestFileNumberGrn

DestFileNumberBlu = FREEFILE
OPEN DestFileBlu$ FOR BINARY AS #DestFileNumberBlu

DestFilePointer = 0

' Count through the 256 source files
FOR SrcFileCounter = 0 TO 255

    ' Construct the Source File name string for each file in turn
    SrcNum$ = STR$(SrcFileCounter)
    SrcNum$ = RIGHT$(SrcNum$, LEN(SrcNum$) - 1)
    IF LEN(SrcNum$) < 3 THEN SrcNum$ = "0" + SrcNum$
    IF LEN(SrcNum$) < 3 THEN SrcNum$ = "0" + SrcNum$
    SrcFile$ = DigitFile$ + SrcNum$ + ".raw"
    PRINT SrcFile$

    ' Open the current source file, and copy it, byte by byte into the destination file
    SrcFileNumber = FREEFILE
    OPEN SrcFile$ FOR BINARY AS #SrcFileNumber

    FOR SrcFilePxlCounter = 0 TO 2047

        y = 2047 - (32 * (SrcFilePxlCounter AND 63))
        x = 31 - (((2048 + (SrcFilePxlCounter AND 1984)) / 64) AND 31)
        SrcFilePointer = x + y

        GET #SrcFileNumber, SrcFilePointer + 1, SrcFileDataByte

        DestFileDataByte = SrcFileDataByte

        PUT #DestFileNumberRed, DestFilePointer + 1, DestFileDataByte
        PUT #DestFileNumberGrn, DestFilePointer + 1, DestFileDataByte
        PUT #DestFileNumberBlu, DestFilePointer + 1, DestFileDataByte

        DestFilePointer = DestFilePointer + 1

    NEXT SrcFilePxlCounter
    CLOSE #SrcFileNumber

NEXT SrcFileCounter
CLOSE
' #DestFileNumber

PRINT "All done!"
END


